
.. .. sectnum::
..   :depth: 4
..   :start: 1
..   :suffix: .

Installation
------------

You can download the trollsift source code from github,::

  $ git clone https://github.com/pytroll/trollsift.git

and then run::

  $ python setup.py install

Testing
++++++++

To check if your python setup is compatible with trollsift,
you can run the test suite using nosetests,::

  $ cd trollsift
  $ nosetests -v tests/

